==> dde-shell_1.0.10.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="162"/>
        <source>Indicator Style</source>
        <translation>Jelölő stíéusa</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="164"/>
        <source>Fashion Mode</source>
        <translation>Stílusos mód</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="169"/>
        <source>Efficient Mode</source>
        <translation>Hatékony mód</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="175"/>
        <source>Alignment</source>
        <translation>Igazítás</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="206"/>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="194"/>
        <source>Position</source>
        <translation>Pozíció</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="179"/>
        <source>Align Left</source>
        <translation>Igazítás Balra</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="181"/>
        <source>Align Top</source>
        <translation>Igazítás Fentre</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="188"/>
        <source>Align Center</source>
        <translation>Igazítás Középre</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="196"/>
        <source>Top</source>
        <translation>Fent</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="201"/>
        <source>Bottom</source>
        <translation>Lent</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="211"/>
        <source>Right</source>
        <translation>Jobb</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="217"/>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="219"/>
        <source>Keep Shown</source>
        <translation>Folyamatosan látható</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="224"/>
        <source>Keep Hidden</source>
        <translation>Maradjon rejtve</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="230"/>
        <source>Smart Hide</source>
        <translation>Intelligens elrejtés</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="237"/>
        <source>Dock Settings</source>
        <translation>Dokkoló beállításai</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.36.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Jelölő stíéusa</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Stílusos mód</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Hatékony mód</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Klasszikus mód</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Középre igazított mód</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Pozíció</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Fent</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Lent</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Jobb</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Folyamatosan látható</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Maradjon rejtve</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Intelligens elrejtés</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Dokkoló beállításai</translation>
    </message>
</context>
</TS>
